<h1 align="center">

  <br>

  <a href="https://github.com/dmitrijkotov/b0mb3r"><img src="https://emojipedia-us.s3.dualstack.us-west-1.amazonaws.com/thumbs/120/apple/237/bomb_1f4a3.png" alt="b0mb3r"></a>

  <br>

  b0mb3r

  <br>

</h1>



<h4 align="center">Открытый и бесплатный СМС бомбер</h4>


Данный репозиторий создан с целью сохранения проекта [b0mb3r](https://github.com/crinny/b0mb3r) (удалён)

## Установка

1. Установите Python версии не ниже 3.7. Сделать это можно так:
 
    <h3>Для Windows</h3>
 
    Скачайте установщик с [официального сайта](https://www.python.org/downloads/) и запустите его. Убедитесь, что при установке отметили галочку ![Add Python to PATH](https://user-images.githubusercontent.com/42045258/69171091-557d2780-0b0c-11ea-8adf-7f819357f041.png)
 
    <h3>Для Android</h3>
 
    Установите приложение [Termux](https://play.google.com/store/apps/details?id=com.termux), запустите его и введите команду `pkg install python clang make openssl -y`.
 
2. Введите следующую команду ([куда?](http://comp-profi.com/kak-vyzvat-komandnuyu-stroku-ili-konsol-windows/)):
 
```sh
pip3 install db0mb3r -U
```
 
## Запуск
 
Всё просто! Введите команду `b0mb3r` или `bomber` и интерфейс бомбера будет запущен. Команда доступна из любой директории.
 

Канал с новостями о разработке в Telegram: [@b0mb3rch](https://t.me/b0mb3rch).



## Лицензия

<!--- Не надо это удалять, пожалуйста 😐  -->

Проект распространяется под лицензией [Mozilla Public License 2.0](https://github.com/crinny/b0mb3r/blob/master/LICENSE). Скачивая программное обеспечение из [этого](https://github.com/crinny/b0mb3r) репозитория, вы соглашаетесь с ней. По условиям лицензии вы обязаны выкладывать исходный код ваших модификаций под той же лицензией.

